# Changelog

## [0.4.0] - 2025-02-07

- **feat**: implement `teams.create` method
- **feat**: implement `channels.get_by_id` method
- **feat**: implement `users.get_by_id` method

## [0.3.0] - 2025-02-07

- **feat**: implement `users.get_by_username` method
- **feat**: implement `channels.direct` method
